rai\_toolbox.perturbations.AdditivePerturbation
===============================================

.. currentmodule:: rai_toolbox.perturbations

.. autoclass:: AdditivePerturbation

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~AdditivePerturbation.__init__

   